
==================
Question Answering
==================

Resources
---------

* `awesome question answering <https://github.com/dapurv5/awesome-question-answering>`_


Papers
------

* [NIPS13] `Reasoning with Neural Tensor Networks for Knowledge Base Completion <https://papers.nips.cc/paper/5028-reasoning-with-neural-tensor-networks-for-knowledge-base-completion.pdf>`_
* [14.04] `Open Question Answering with Weakly Supervised Embedding Models <https://arxiv.org/pdf/1404.4326.pdf>`_
* [14.06] `Question Answering with Subgraph Embeddings <https://arxiv.org/pdf/1406.3676v3.pdf>`_
* [14.09] `Sequence to Sequence Learning With Neural Networks <https://arxiv.org/abs/1409.3215>`_
* [14.09] `Neural Machine Translation by jointly learning to align and translate <https://arxiv.org/pdf/1409.0473v7.pdf>`_
* [14.10] `Memory Networks <http://arxiv.org/pdf/1410.3916v11.pdf>`_
* [14.10] `Neural Turing Machines <https://arxiv.org/abs/1410.5401>`_
* [15.02] `Towards AI-Complete Question Answering: A set of prerequisite toy tasks <http://arxiv.org/pdf/1502.05698v10.pdf>`_
* [15.03] `End-To-End Memory Networks <http://arxiv.org/abs/1503.08895>`_
* [15.06] `Large Scale simple question answering with Memory Networks <https://arxiv.org/pdf/1506.02075v1.pdf>`_
* [15.06] `Teaching machines to read and comprehend <https://arxiv.org/pdf/1506.03340.pdf>`_
* [15.06] `Neural Conversation Model <https://arxiv.org/pdf/1506.05869v1.pdf>`_
* [15.06] `Ask Me Anything: Dynamic Memory Networks for Natural Language Processing <http://arxiv.org/pdf/1506.07285v5.pdf>`_
* [15.08] `Applying Deep Learning to answer selection: A study and an open task <https://arxiv.org/pdf/1508.01585v2.pdf>`_
* [15.11] `Gated Graph Sequence Neural Networks <https://arxiv.org/abs/1511.05493>`_
* [EMNLP15] `Traversing Knowledge Graphs in Vector Space <http://www.emnlp2015.org/proceedings/EMNLP/pdf/EMNLP038.pdf>`_
* [ACL15] `Semantic Parsing via Staged Query Graph Generation: Question Answering with Knowledge Base <https://www.microsoft.com/en-us/research/wp-content/uploads/2016/02/ACL15-STAGG.pdf>`_
* [16.01] `Learning to Compose Neural Networks for Question Answering <https://arxiv.org/abs/1601.01705>`_
* [16.02] `Recurrent Neural Network Grammar <https://arxiv.org/pdf/1602.07776v4.pdf>`_
* [16.05] `Hierarchical Memory Networks <https://arxiv.org/abs/1605.07427>`_
* [16.05] `Learning End-to-End Goal-Oriented dialog <https://arxiv.org/pdf/1605.07683v2.pdf>`_
* [16.06] `Query Reduction Networks For Question Answering <https://arxiv.org/pdf/1606.04582.pdf>`_
* [16.06] `Learning Distributed Representations for Rooted Subgraphs from Large Graphs: Subgraph2Vec <https://arxiv.org/pdf/1606.08928.pdf>`_
* [16.06] `Question Answering over Knowledge Base With Neural Attention Combining Global Knowledge Information <https://arxiv.org/pdf/1606.00979v1.pdf>`_
* [16.06] `Key-Value Memory Networks for directly understanding documents <https://arxiv.org/pdf/1606.03126v1.pdf>`_
* [16.11] `Gaussian Attention Model and its Application to Knowledge Base Embedding and Question Answering <https://arxiv.org/pdf/1611.02266.pdf>`_
* [IS16] `End-to-End Memory Networks with Knowledge Carryover for Multi-Turn Spoken Language Understanding <https://www.microsoft.com/en-us/research/wp-content/uploads/2016/06/IS16_ContextualSLU.pdf>`_
* [ACL16] `Compositional Learning of Embeddings for Relation Paths in Knowledge Bases and Texts <https://www.microsoft.com/en-us/research/wp-content/uploads/2016/06/acl2016relationpaths-1.pdf>`_
* [ACL16] `Value of Semantic Parse Labeling for KBQA <https://www.microsoft.com/en-us/research/wp-content/uploads/2016/08/acl2016-webqsp.pdf>`_
* [KDD16] `Scalable Feature Learning for networks: Node2Vec <https://cs.stanford.edu/people/jure/pubs/node2vec-kdd16.pdf>`_
* [Nature16] `Hybrid computing using a neural network with dynamic external memory <http://www.nature.com/nature/journal/v538/n7626/full/nature20101.html>`_
